@@ -1,8 +1,9 @@
 module SciMLLogging
 
 import Logging
-using LoggingExtras
-using Preferences
+using Logging: NullLogger, current_logger
+using LoggingExtras: EarlyFilteredLogger, FileLogger, TeeLogger
+using Preferences: @load_preference, @set_preferences!
 
 include("verbosity.jl")
 include("utils.jl")
@@ -16,6 +17,6 @@ export verbosity_to_int, verbosity_to_bool
 export SciMLLogger
 export set_logging_backend, get_logging_backend
 export None, Minimal, Standard, Detailed, All
-export @define_verbosity_specifier
+export @verbosity_specifier
 
 end
